@@ -1,25 +1,31 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "المهام",
     "Important" : "مهم",
     "Today" : "اليوم",
     "Week" : "أسبوع",
     "All" : "الكل",
     "Current" : "الحالي",
     "Completed" : "مكتمل",
-    "Delete" : "حذف ",
+    "Tasks" : "المهام",
+    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
+    "can edit" : "يمكن التعديل",
+    "New List" : "قائمة جديدة",
     "Cancel" : "إلغاء",
-    "No errors" : "لا توجد أخطاء",
-    "Default" : "افتراضي",
-    "Tomorrow" : "غدا",
+    "Save" : "حفظ",
+    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
     "Edit" : "تعديل",
     "Download" : "تحميل",
-    "Save" : "حفظ",
-    "New List" : "قائمة جديدة",
-    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
-    "Settings" : "الإعدادات",
+    "Delete" : "حذف ",
+    "Unshare" : "إلغاء المشاركة",
     "Hidden" : "مخفي",
-    "Automatic" : "تلقائي"
+    "Automatic" : "تلقائي",
+    "No errors" : "لا توجد أخطاء",
+    "Last modified" : "آخر تعديل",
+    "Tomorrow" : "غدا",
+    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
+    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
+    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
+    "An error occurred" : "طرأ هناك خطأ"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
