@@ -1,29 +1,30 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Tapşırıqlar",
     "Important" : "Vacib",
     "Today" : "Bu gün",
     "Week" : "Həftə",
     "All" : "Hamısı",
     "Current" : "Mövcud",
     "Completed" : "Bitmişdir",
-    "Delete" : "Sil",
+    "Tasks" : "Tapşırıqlar",
+    "can edit" : "dəyişmək olar",
+    "New List" : "Yeni Siyahı",
     "Cancel" : "Dayandır",
-    "Default" : "Susmaya görə",
+    "Save" : "Saxla",
+    "An empty name is not allowed." : "Boş ada izin verilmir.",
+    "Edit" : "Dəyişiklik et",
+    "Download" : "Yüklə",
+    "Delete" : "Sil",
+    "Unshare" : "Paylaşımı durdur",
+    "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
+    "Hidden" : "Gizli",
+    "Visible" : "Görünən",
+    "Automatic" : "Avtomatik",
     "_%n Completed Task_::_%n Completed Tasks_" : ["\"%s\" Bitmiş Tapşırıqlar","Completed Tasks"],
     "Tomorrow" : "Sabah",
     "Set start date" : "Başlanğıc tarixini işə sal",
     "Set due date" : "Vaxtı təyin et",
-    "Task not found!" : "Tapşırıq tapılmadı!",
-    "Edit" : "Dəyişiklik et",
-    "Download" : "Yüklə",
-    "Save" : "Saxla",
-    "New List" : "Yeni Siyahı",
-    "An empty name is not allowed." : "Boş ada izin verilmir.",
-    "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
-    "Hidden" : "Gizli",
-    "Visible" : "Görünən",
-    "Automatic" : "Avtomatik"
+    "Task not found!" : "Tapşırıq tapılmadı!"
 },
 "nplurals=2; plural=(n != 1);");
