@@ -1,28 +1,29 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "কর্ম",
     "Important" : "গুরুত্বপূর্ণ",
     "Today" : "আজ",
     "Week" : "সপ্তাহ",
     "All" : "সবাই",
     "Current" : "বর্তমান",
     "Completed" : "সুসম্পন্ন",
-    "Delete" : "মুছে",
+    "Tasks" : "কর্ম",
+    "can edit" : "সম্পাদনা করতে পারবেন",
+    "New List" : "নতুন তালিকা",
     "Cancel" : "বাতিল",
-    "Default" : "পূর্বনির্ধারিত",
-    "_%n Completed Task_::_%n Completed Tasks_" : ["%n সুসম্পন্ন কাজ","%n সুসম্পন্ন কাজ"],
-    "Tomorrow" : "আগামীকাল",
-    "Set start date" : "আরম্ভের তারিখ নির্ধারণ করুন",
-    "Set due date" : "কার্যকারিতার তারিখ নির্ধারণ করুন",
+    "Save" : "সংরক্ষণ",
+    "An empty name is not allowed." : "একটি শুন্য নাম গ্রহণযোগ্য নয়।",
     "Edit" : "সম্পাদনা",
     "Download" : "ডাউনলোড",
-    "Save" : "সংরক্ষণ",
-    "New List" : "নতুন তালিকা",
-    "An empty name is not allowed." : "একটি শুন্য নাম গ্রহণযোগ্য নয়।",
+    "Delete" : "মুছে",
+    "Unshare" : "ভাগাভাগি বাতিল ",
     "Visibility of Smart Collections" : "চটপট সংগ্রহের দর্শনযোগ্যতা",
     "Hidden" : "লুকনো",
     "Visible" : "দর্শনযোগ্য",
-    "Automatic" : "স্বয়ংক্রিয়"
+    "Automatic" : "স্বয়ংক্রিয়",
+    "_%n Completed Task_::_%n Completed Tasks_" : ["%n সুসম্পন্ন কাজ","%n সুসম্পন্ন কাজ"],
+    "Tomorrow" : "আগামীকাল",
+    "Set start date" : "আরম্ভের তারিখ নির্ধারণ করুন",
+    "Set due date" : "কার্যকারিতার তারিখ নির্ধারণ করুন"
 },
 "nplurals=2; plural=(n != 1);");
