@@ -1,22 +1,34 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Tareas",
     "Important" : "Importante",
     "Today" : "Hoy",
     "Week" : "Semana",
     "All" : "Todos",
     "Current" : "Actual",
     "Completed" : "Completado",
-    "Delete" : "Borrar",
+    "Tasks" : "Tareas",
+    "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "can edit" : "puede editar",
+    "New List" : "Nueva Lista",
     "Cancel" : "Cancelar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "No se permite un nombre vacío.",
+    "Edit" : "Editar",
+    "Download" : "Descargar",
+    "Delete" : "Borrar",
+    "Unshare" : "Dejar de compartir",
+    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
+    "Hidden" : "Oculto",
+    "Visible" : "Visible",
+    "Automatic" : "Automático",
     "Change sort order" : "Cambiar el criterio para ordenar",
-    "Default" : "Predeterminado",
-    "Due date" : "Fecha de vencimiento",
     "Start date" : "Fecha de inicio",
+    "Due date" : "Fecha de vencimiento",
+    "Last modified" : "Última modificación",
     "Priority" : "Prioridad",
-    "Manually" : "Manualmente",
     "Alphabetically" : "Alfabéticamente",
+    "Manually" : "Manualmente",
     "Task is completed" : "La tarea ha sido completada",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
     "Tomorrow" : "Mañana",
@@ -24,17 +36,8 @@ OC.L10N.register(
     "Set due date" : "Establecer fecha de vencimiento",
     "All day" : "Todo el día",
     "Task not found!" : "¡Tarea no encontrada!",
-    "%s %% completed" : "%s %% terminado",
-    "Edit" : "Editar",
-    "Download" : "Descargar",
-    "Save" : "Guardar",
-    "New List" : "Nueva Lista",
-    "The name \"%s\" is already used." : "El nombre \"%s\" ya está en uso.",
-    "An empty name is not allowed." : "No se permite un nombre vacío.",
-    "Settings" : "Configuraciones ",
-    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
-    "Hidden" : "Oculto",
-    "Visible" : "Visible",
-    "Automatic" : "Automático"
+    "When shared show full event" : "Al compartir, mostrar el evento completo",
+    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
+    "When shared hide this event" : "Al compartir, ocultar este evento "
 },
 "nplurals=2; plural=(n != 1);");
