@@ -5,12 +5,13 @@ OC.L10N.register(
     "Week" : "Շաբաթ",
     "Current" : "Ընթացիկ",
     "Completed" : "Ավարտվեց",
-    "Delete" : "Ջնջել",
+    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
+    "can edit" : "կարող է խմբագրել",
     "Cancel" : "Չեղարկել",
-    "Default" : "Լռելյայն",
+    "Save" : "Պահել",
     "Edit" : "Խմբագրել",
     "Download" : "Ներբեռնել",
-    "Save" : "Պահել",
-    "Settings" : "Կարգավորումներ"
+    "Delete" : "Ջնջել",
+    "Unshare" : "Չկիսվել"
 },
 "nplurals=2; plural=(n != 1);");
