@@ -1,30 +1,32 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Tugas",
     "Important" : "Penting",
     "Today" : "Hari Ini",
     "Week" : "Minggu",
     "All" : "Semua",
     "Current" : "Saat ini",
     "Completed" : "Selesai",
-    "Delete" : "Hapus",
+    "Tasks" : "Tugas",
+    "Share with users or groups" : "Bagi dengan pengguna atau grup",
+    "can edit" : "dapat menyunting",
+    "New List" : "Daftar Baru",
     "Cancel" : "Batal",
-    "Default" : "Default",
+    "Save" : "Simpan",
+    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
+    "Edit" : "Sunting",
+    "Download" : "Unduh",
+    "Delete" : "Hapus",
+    "Unshare" : "Batalkan berbagi",
+    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
+    "Hidden" : "Sembunyi",
+    "Visible" : "Tampak",
+    "Automatic" : "Otomatis",
+    "Last modified" : "Terakhir diubah",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
     "Tomorrow" : "Besok",
     "Set start date" : "Atur tanggal mulai",
     "Set due date" : "Atur tanggal jatuh tempo",
-    "Task not found!" : "Tugas tidak ditemukan!",
-    "Edit" : "Sunting",
-    "Download" : "Unduh",
-    "Save" : "Simpan",
-    "New List" : "Daftar Baru",
-    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
-    "Settings" : "Pengaturan",
-    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
-    "Hidden" : "Sembunyi",
-    "Visible" : "Tampak",
-    "Automatic" : "Otomatis"
+    "Task not found!" : "Tugas tidak ditemukan!"
 },
 "nplurals=1; plural=0;");
