@@ -1,12 +1,14 @@
 OC.L10N.register(
     "tasks",
     {
+    "Today" : "Today",
     "All" : "﻿ಎಲ್ಲಾ",
-    "Delete" : "﻿ಅಳಿಸಿ",
+    "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
     "Cancel" : "﻿ರದ್ದು",
-    "Default" : "ಆರಂಭದ ಪ್ರತಿ",
+    "Save" : "﻿ಉಳಿಸಿ",
     "Edit" : "ಸಂಪಾದಿಸು",
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
-    "Save" : "﻿ಉಳಿಸಿ"
+    "Delete" : "﻿ಅಳಿಸಿ",
+    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ"
 },
 "nplurals=2; plural=(n > 1);");
