@@ -3,10 +3,11 @@ OC.L10N.register(
     {
     "Today" : "Hari ini",
     "Week" : "Minggu",
-    "Delete" : "Padam",
+    "can edit" : "boleh mengubah",
     "Cancel" : "Batal",
+    "Save" : "Simpan",
     "Edit" : "Sunting",
     "Download" : "Muat turun",
-    "Save" : "Simpan"
+    "Delete" : "Padam"
 },
 "nplurals=1; plural=0;");
