@@ -1,30 +1,30 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Prètzfaches",
     "Important" : "Important",
     "Today" : "Uèi",
     "Week" : "Aquesta setmana",
     "All" : "Tot",
     "Current" : "En aqueste moment",
     "Completed" : "Acabat",
-    "Delete" : "Suprimir",
+    "Tasks" : "Prètzfaches",
+    "can edit" : "pòt modificar",
+    "New List" : "Novèla lista",
     "Cancel" : "Anullar",
-    "Default" : "Defaut",
+    "Save" : "Enregistrar",
+    "An empty name is not allowed." : "Un nom void es pas autorizat.",
+    "Edit" : "Modificar",
+    "Download" : "Telecargar",
+    "Delete" : "Suprimir",
+    "Unshare" : "Partejar pas",
+    "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
+    "Hidden" : "Amagat",
+    "Visible" : "Visible",
+    "Automatic" : "Automatic",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
     "Tomorrow" : "Deman",
     "Set start date" : "Especificar la data de començament",
     "Set due date" : "Especificar la data d'escasença",
-    "Task not found!" : "Prètzfach pas trobat !",
-    "Edit" : "Modificar",
-    "Download" : "Telecargar",
-    "Save" : "Enregistrar",
-    "New List" : "Novèla lista",
-    "An empty name is not allowed." : "Un nom void es pas autorizat.",
-    "Settings" : "Paramètres",
-    "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
-    "Hidden" : "Amagat",
-    "Visible" : "Visible",
-    "Automatic" : "Automatic"
+    "Task not found!" : "Prètzfach pas trobat !"
 },
 "nplurals=2; plural=(n > 1);");
