@@ -1,14 +1,16 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "کام",
     "Important" : "اہم",
     "Today" : "آج",
     "Week" : "ہفتہ",
-    "Delete" : "حذف کریں",
+    "Tasks" : "کام",
+    "can edit" : "تبدیل کر سکے ھیں",
     "Cancel" : "منسوخ کریں",
+    "Save" : "حفظ",
     "Edit" : "تدوین کریں",
     "Download" : "ڈاؤن لوڈ",
-    "Save" : "حفظ"
+    "Delete" : "حذف کریں",
+    "Unshare" : "شئیرنگ ختم کریں"
 },
 "nplurals=2; plural=(n != 1);");
